@@ -1,15 +1,12 @@
 #!/usr/bin/env python
 
-
-
 import pprint
 import os
 import ConfigParser
 import MySQLdb
 import hashlib
 import argparse
-
-
+import sys
 
 pp = pprint.PrettyPrinter(indent=0)
     
@@ -25,11 +22,15 @@ class FGEucaMetricsDB(object):
         config.read(cfgfile)
 
         #db parameters
-        dbhost = config.get('EucaLogDB', 'host')
-        dbport = int(config.get('EucaLogDB', 'port'))
-        dbuser = config.get('EucaLogDB', 'user')
-        dbpasswd = config.get('EucaLogDB', 'passwd')
-        dbname = config.get('EucaLogDB', 'db')
+        try:
+            dbhost = config.get('EucaLogDB', 'host')
+            dbport = int(config.get('EucaLogDB', 'port'))
+            dbuser = config.get('EucaLogDB', 'user')
+            dbpasswd = config.get('EucaLogDB', 'passwd')
+            dbname = config.get('EucaLogDB', 'db')
+        except ConfigParser.NoSectionError:
+            print cfgfile + " does not exist"
+            sys.exit()
 
 	#table 
 	self.tablename = "instance" #default table
@@ -90,8 +91,11 @@ class FGEucaMetricsDB(object):
 
     # destructor
     def __del__(self):
-        self.cursor.close()
-        self.conn.close()
+        try:
+            self.cursor.close()
+            self.conn.close()
+        except:
+            pass
 
     # help function to format values to be inserted into mysql db
     def _fmtstr(self, astr):
@@ -102,7 +106,7 @@ class FGEucaMetricsDB(object):
         return ret
 
     # read from the database.
-    def read(self, querydict={}):
+    def read(self, querydict={}, optional=""):
         querystr = "";
         if querydict:
             for key in querydict:
@@ -111,10 +115,10 @@ class FGEucaMetricsDB(object):
                 if querystr != "":
                     querystr += " and "
                 querystr += astr            
-                #print "qstr:->" + querystr + "<---"
-                rquery = "SELECT * FROM " + self.tablename + " where " + querystr
+                print "qstr:->" + querystr + "<---"
+                rquery = "SELECT * FROM " + self.tablename + " where " + querystr + optional
         else:
-            rquery = "SELECT * from " + self.tablename
+            rquery = "SELECT * from " + self.tablename + optional
             
         self.cursor.execute(rquery)
         rows = self.cursor.fetchall()
@@ -489,7 +493,7 @@ def command_clean_database():
 			help="db name")
     parser.add_argument("-w", dest="where_clause",
 			help="WHERE clauses")
-    parser.add_argument("--conf", dest="conf", default=def_conf,
+    parser.add_argument("-C", "--conf", dest="conf", default=def_conf,
 			help="configuraton file of the database to be used")
     args = parser.parse_args()
 
